@@ -29,7 +29,7 @@ from aesara.graph.op import Op
 import pymc as pm
 
 from pymc.aesaraf import floatX
-from pymc.data import Data
+from pymc.data import Data, MutableData
 from pymc.distributions import (
     Bernoulli,
     Beta,
@@ -86,6 +86,15 @@ class TestStepMethods:
             s = stat(group[var].sel(chain=0), axis=0)
             close_to(s, value, bound, name)
 
+    def check_stat_dtype(self, step, idata):
+        # TODO: This check does not confirm the announced dtypes are correct as the
+        #  sampling machinery will convert them automatically.
+        for stats_dtypes in getattr(step, "stats_dtypes", []):
+            for stat, dtype in stats_dtypes.items():
+                if stat == "tune":
+                    continue
+                assert idata.sample_stats[stat].dtype == np.dtype(dtype)
+
     @pytest.mark.parametrize(
         "step_fn, draws",
         [
@@ -139,6 +148,7 @@ class TestStepMethods:
                 random_seed=1,
             )
             self.check_stat(check, idata, step.__class__.__name__)
+            self.check_stat_dtype(idata, step)
 
     def test_step_discrete(self):
         start, model, (mu, C) = mv_simple_discrete()
@@ -156,6 +166,7 @@ class TestStepMethods:
                 random_seed=1,
             )
             self.check_stat(check, idata, step.__class__.__name__)
+            self.check_stat_dtype(idata, step)
 
     @pytest.mark.parametrize("proposal", ["uniform", "proportional"])
     def test_step_categorical(self, proposal):
@@ -174,6 +185,7 @@ class TestStepMethods:
                 random_seed=1,
             )
             self.check_stat(check, idata, step.__class__.__name__)
+            self.check_stat_dtype(idata, step)
 
 
 class TestCompoundStep:
@@ -629,6 +641,9 @@ class TestNutsCheckTrace:
             "perf_counter_diff",
             "perf_counter_start",
             "process_time_diff",
+            "index_in_trajectory",
+            "largest_eigval",
+            "smallest_eigval",
         }
         assert trace.stat_names == expected_stat_names
         for varname in trace.stat_names:
@@ -1094,7 +1109,7 @@ class TestMLDA:
                 intercept = inputs[0][0]
                 x_coeff = inputs[0][1]
 
-                temp = intercept + x_coeff * x + self.pymc_model.bias.get_value()
+                temp = intercept + x_coeff * x + self.pymc_model.bias.data
                 with self.pymc_model:
                     set_data({"model_output": temp})
                 outputs[0][0] = np.array(temp)
@@ -1105,9 +1120,9 @@ class TestMLDA:
 
         with Model() as coarse_model_0:
             bias = Data("bias", 3.5 * np.ones(y.shape, dtype=p))
-            mu_B = Data("mu_B", -1.3 * np.ones(y.shape, dtype=p))
-            Sigma_B = Data("Sigma_B", np.zeros((y.shape[0], y.shape[0]), dtype=p))
-            model_output = Data("model_output", np.zeros(y.shape, dtype=p))
+            mu_B = MutableData("mu_B", -1.3 * np.ones(y.shape, dtype=p))
+            Sigma_B = MutableData("Sigma_B", np.zeros((y.shape[0], y.shape[0]), dtype=p))
+            model_output = MutableData("model_output", np.zeros(y.shape, dtype=p))
             Sigma_e = Data("Sigma_e", s)
 
             # Define priors
@@ -1125,9 +1140,9 @@ class TestMLDA:
 
         with Model() as coarse_model_1:
             bias = Data("bias", 2.2 * np.ones(y.shape, dtype=p))
-            mu_B = Data("mu_B", -2.2 * np.ones(y.shape, dtype=p))
-            Sigma_B = Data("Sigma_B", np.zeros((y.shape[0], y.shape[0]), dtype=p))
-            model_output = Data("model_output", np.zeros(y.shape, dtype=p))
+            mu_B = MutableData("mu_B", -2.2 * np.ones(y.shape, dtype=p))
+            Sigma_B = MutableData("Sigma_B", np.zeros((y.shape[0], y.shape[0]), dtype=p))
+            model_output = MutableData("model_output", np.zeros(y.shape, dtype=p))
             Sigma_e = Data("Sigma_e", s)
 
             # Define priors
@@ -1146,7 +1161,7 @@ class TestMLDA:
         # fine model and inference
         with Model() as model:
             bias = Data("bias", np.zeros(y.shape, dtype=p))
-            model_output = Data("model_output", np.zeros(y.shape, dtype=p))
+            model_output = MutableData("model_output", np.zeros(y.shape, dtype=p))
             Sigma_e = Data("Sigma_e", s)
 
             # Define priors
@@ -1253,9 +1268,9 @@ class TestMLDA:
 
             with Model() as coarse_model_0:
                 if aesara.config.floatX == "float32":
-                    Q = Data("Q", np.float32(0.0))
+                    Q = MutableData("Q", np.float32(0.0))
                 else:
-                    Q = Data("Q", np.float64(0.0))
+                    Q = MutableData("Q", np.float64(0.0))
 
                 # Define priors
                 intercept = Normal("Intercept", true_intercept, sigma=1)
@@ -1270,9 +1285,9 @@ class TestMLDA:
 
             with Model() as coarse_model_1:
                 if aesara.config.floatX == "float32":
-                    Q = Data("Q", np.float32(0.0))
+                    Q = MutableData("Q", np.float32(0.0))
                 else:
-                    Q = Data("Q", np.float64(0.0))
+                    Q = MutableData("Q", np.float64(0.0))
 
                 # Define priors
                 intercept = Normal("Intercept", true_intercept, sigma=1)
@@ -1287,9 +1302,9 @@ class TestMLDA:
 
             with Model() as model:
                 if aesara.config.floatX == "float32":
-                    Q = Data("Q", np.float32(0.0))
+                    Q = MutableData("Q", np.float32(0.0))
                 else:
-                    Q = Data("Q", np.float64(0.0))
+                    Q = MutableData("Q", np.float64(0.0))
 
                 # Define priors
                 intercept = Normal("Intercept", true_intercept, sigma=1)
